@@ -1,6 +1,7 @@
 package App::FatPacker::Simple::Tutorial;
-use strict;
+use v5.16;
 use warnings;
+
 1;
 __END__
 
